@@ -5,9 +5,9 @@
 ;; Author: Luis Henriquez-Perez <luis@luishp.xyz>, Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.4
-;; Package-Requires: ((emacs "27.1") (compat "29.1.4.4") (corfu "1.4"))
-;; Homepage: https://github.com/minad/corfu
+;; Version: 1.6
+;; Package-Requires: ((emacs "28.1") (compat "30") (corfu "1.6"))
+;; URL: https://github.com/minad/corfu
 
 ;; This file is part of GNU Emacs.
 
@@ -146,9 +146,5 @@ TWO is non-nil if two keys should be displayed."
   (when (corfu-quick-jump)
     (corfu-complete)))
 
-;; Emacs 28: Do not show Corfu commands in M-X
-(dolist (sym '(corfu-quick-jump corfu-quick-insert corfu-quick-complete))
-  (put sym 'completion-predicate #'ignore))
-
 (provide 'corfu-quick)
 ;;; corfu-quick.el ends here
